
#ifndef  CANVASMANAGERALG_H
#define CANVASMANAGERALG_H

#include "Headers.h"
#include "Event.h"
#include "SystemAlg.h"

#include "TCanvas.h"
#include "TPostScript.h"

/*! -Class:   CanvasManagerAlg
  - Author:   Michel Lefebvre
  - Date:     08/03/2004
  - Description: CanvasManagerAlg is a class designed to manage Canvases, Pads and Postscript
  */
class CanvasManagerAlg : public SystemAlg {
public:

  /** The user should never need to use this contructor
    * @param event A pointer in the event. Information contained in the event
    *                             gets refreshed before the execute method is run
    * @param hecGeom Pointer to the singleton Geometry object
    * @param runHeader Pointer to the singleton HecRunHeader object
    */

  CanvasManagerAlg(Event* event, Geometry* hecGeom, Headers* runHeader);

  //! Gets run once at the begining of the event Loop
  bool initialize();

  //! Gets run for every event
  bool execute();

  //! Gets run after all events have been executed
  bool finalize();

  // set canvas
  void setCanvas(string canvasBaseTitle, int canvasNx = 3, int canvasNy = 3, int canvasWx = 1000, int canvasWy = 774);

  // update canvas
  void updateCanvas();

  // get next canvas
  void getNextPad();

  // set postscript
  void setPostScript(string postScriptFileName);

  // close postscript
  void closePostScript();

private:
  //################################
  // private methods

  // get next canvas
  TCanvas* getNextCanvas();

  // open postscript
  void openPostScript();

  //################################
  // private variables

  Geometry* m_geo;
  Event* m_event;
  Headers* m_runHeader;

  //
  int m_canvasX;      // x of next canvas
  int m_canvasY;      // y of next canvas
  int m_canvasX0;     // x of first canvas
  int m_canvasY0;     // y of first canvas
  int m_canvasNo;     // next canvas number
  int m_canvasPadNo;  // next pad number (in a canvas series)
  int m_canvasNx;     // number of pads in x per canvas
  int m_canvasNy;     // number of pads in y per canvas
  int m_canvasDx;     // dx between canvas
  int m_canvasDy;     // dy between canvas
  int m_canvasWx;     // x width of canvas
  int m_canvasWy;     // y width of canvas
  string m_canvasBaseTitle;
  vector<TCanvas*> m_canvasVector;
  string m_postScriptFileName;
  TPostScript* m_psFile;
};

#endif
