
#ifndef  RUNSTATISTICSALG_H
#define RUNSTATISTICSALG_H

//#include "HecRunHeader2001v0.h"
#include "Headers.h"
//#include "HecEvent.h"
#include "Event.h"
#include "SystemAlg.h"

/*! -Class:   RunStatisticsAlg
  - Author:   Michel Lefebvre
  - Date:     21/07/2003
  - Description: RunStatisticsAlg is a simple class designed to print some useful run statistics
                 in its finalize() method
  */
class RunStatisticsAlg : public SystemAlg {
public:

  /** The user should never need to use this contructor
    * @param event A pointer in the event. Information contained in the event
    *                             gets refreshed before the execute method is run
    * @param hecGeom Pointer to the singleton Geometry object
    * @param runHeader Pointer to the singleton HecRunHeader object
    */

  RunStatisticsAlg(Event* event, Geometry* hecGeom, Headers* runHeader);

  //! Gets run once at the begining of the event Loop
  bool initialize();

  //! Gets run for every event
  bool execute();

  //! Gets run after all events have been executed
  bool finalize();

private:

  //################################
  // private variables

  Geometry* m_geo;
  Event* m_event;
  Headers* m_runHeader;

  // timing type
  int m_timingType; // > 0 global cubic time

  // trigger statistics (physics,electron,muon,pi,random)
  vector<int> m_triggerStat;
  int m_triggers;          // total number of triggers
  int m_badGlobalTiming;   // number of bad global timing triggers
};

#endif
