
#ifndef  USERALG_H
#define USERALG_H

#include "Event.h"
#include "Geometry.h"
#include "Headers.h"
#include "SystemAlg.h"

#include "NoiseAlg.h"

/*! -Class:      UserAlg
  - Author:      Ian Gable (igable@uvic.ca)
  - Date:        08/08/2003
  - Description: UserAlg is a simple class designed to be modified by the user.
                 The user must add code to the initialize, excute and finalize methods
                 as well as adding any member variables.  SystemAlg's can be added
                 in the constructor.
  */
class UserAlg : public SystemAlg {
public:

  /** The user should never need to use this contructor
    * @param event A pointer in the event. Information contained in the event
    *              gets refreshed before the execute method is run
    * @param hecGeom Pointer to the singleton Geometry object
    * @param runHeader Pointer to the singleton HecRunHeader object
    */

  UserAlg(Event* event, Geometry* hecGeom, Headers* runHeader);

  //! Gets run once at the begining of the event Loop
  bool initialize();

  //! Gets run for every event
  bool execute();

  //! Gets run after all events have been executed
  bool finalize();

private:
  Geometry* m_geo;
  Event* m_event;
  Headers* m_runHeader;

  // here put pointers to the system algorithms you wish to use
  NoiseAlg* m_noise;

  //################################
  //### insert your member variables here


  //################################
};

#endif
