#include "Event.h"

using std::cout;
using std::endl;
using std::map;
using std::vector;

Event::Event()
{
}

//==========Hec Portion==================

bool Event::addHecCell(HecCell hecCell){
  m_hecCellMap[hecCell.adcNumber()] = hecCell;
  return true;
}

HecCell* Event::hecCell(int adcNumber){
  if (m_hecCellMap.count(adcNumber) == 1) {  // the entry exists
    return &m_hecCellMap[adcNumber]; // note that we are returning a pointer to the cell
  } else {
    cout << "No data for this cell; cell number: "
         << adcNumber << endl;
  }
}

void Event::clearHecCells()
{
  m_hecCellMap.clear();
  m_hecTriggerVector.clear();
}

int Event::numHecCells(){
  return m_hecCellMap.size();
}

const map<int, HecCell>* Event::hecCellsPointer(){
  return &m_hecCellMap;
}

//note this method will crash if the length of the hecTrigger array changes
void Event::setHecTrigger(unsigned int hecTriggerArray[5]){
  for(int i = 0; i < 5; i++){
    m_hecTriggerVector.push_back(hecTriggerArray[i]);
  }
  processHecTrigger();
}

int Event::getHecTriggerBit(int bit){
  if(bit >= 0 && bit <=4){
    return m_hecTriggerVector[bit];
  } else {
    cout << "Trigger bits accessed out of bounds at:  "
          << bit << endl;
  }
}

void Event::processHecTrigger(){
  if(m_hecTriggerVector[4]){
    m_isHecRandom =true;
  } else {
    m_isHecRandom = false;
  }
  if(m_hecTriggerVector[2]) {
    m_isHecMuon = true;
  } else {
    m_isHecMuon = false;
  }
}

//====================== EmecPortion ============================

bool Event::addEmecCell(EmecCell emecCell){
  m_emecCellMap[emecCell.adcNumber()] = emecCell;
  return true;
}

EmecCell* Event::emecCell(int adcNumber){
  if (m_emecCellMap.count(adcNumber) == 1) {  // the entry exists
    return &m_emecCellMap[adcNumber]; // note that we are returning a pointer to the cell
  } else {
    cout << "No data for this cell; cell number: "
         << adcNumber << endl;
  }
}

void Event::clearEmecCells()
{
  m_emecCellMap.clear();
  m_emecTriggerVector.clear();
}

int Event::numEmecCells(){
  return m_emecCellMap.size();
}

const map<int, EmecCell>* Event::emecCellsPointer(){
  return &m_emecCellMap;
}

//note this method will crash if the length of the hecTrigger array changes
void Event::setEmecTrigger(unsigned int emecTriggerArray[5]){
  for(int i = 0; i < 5; i++){
    m_emecTriggerVector.push_back(emecTriggerArray[i]);
  }
  processEmecTrigger();
}

int Event::getEmecTriggerBit(int bit){
  if(bit >= 0 && bit <=4){
    return m_emecTriggerVector[bit];
  } else {
    cout << "Trigger bits accessed out of bounds at:  "
          << bit << endl;
  }
}

void Event::processEmecTrigger(){
  if(m_emecTriggerVector[4]){
    m_isEmecRandom =true;
  } else {
    m_isEmecRandom = false;
  }
  if(m_emecTriggerVector[2]) {
    m_isEmecMuon = true;
  } else {
    m_isEmecMuon = false;
  }
}

void Event::setBeamChamberInfo(float slope[2], float pos0[2], float xcov[3], float ycov[3]){
  m_bcSlopeX = slope[0];
  m_bcSlopeY = slope[1];
  m_bcXatZ0 = pos0[0];
  m_bcYatZ0 = pos0[1];

  m_bcCovXatZ0 =xcov[0];
  m_bcCovXatSlopeX =xcov[1];
  m_bcCovXatZ0SlopeX =xcov[2];

  m_bcCovYatZ0 = ycov[0];
  m_bcCovYatSlopeY = ycov[1];
  m_bcCovYatZ0SlopeY = ycov[2];
}

vector<float> Event::beamChamberLine(){
  vector<float> beam;
  beam.push_back(m_bcXatZ0);
  beam.push_back(m_bcYatZ0);
  beam.push_back(m_bcSlopeX);
  beam.push_back(m_bcSlopeY);
  return beam;
}

void Event::setGlobalTimingInfo(float tdc_ns, float Globalcubictime, float Globalcubictimesigma){
  m_globalTDCTime = tdc_ns;
  m_globalCubicTime = Globalcubictime;
  m_globalCubicTimeSigma = Globalcubictimesigma;
}
